@@ -1,6 +1,6 @@
 #' Build a Markov Model
 #'
-#' Function \code{build_mm} builds and automatically estimates a Markov model. It is also a shortcut for 
+#' Function \code{build_mm} builds and automatically estimates a Markov model. It is also a shortcut for
 #' constructing a Markov model as a restricted case of an \code{hmm} object.
 #' @export
 #' @param observations An \code{stslist} object (see \code{\link[TraMineR]{seqdef}}) containing
@@ -19,33 +19,37 @@
 #'    \item{\code{n_symbols}}{Number of observed states (in each channel).}
 #'    \item{\code{n_states}}{Number of hidden states.}
 #'    \item{\code{n_channels}}{Number of channels.}
-#'}
+#' }
 #'
 #' @details Unlike the other build functions in \code{seqHMM}, the \code{build_mm} function
-#' automatically estimates the model parameters. In case of no missing values, 
+#' automatically estimates the model parameters. In case of no missing values,
 #' initial and transition probabilities are
 #' directly estimated from the observed initial state probabilities and transition counts.
 #' In case of missing values, the EM algorithm is run once.
-#' 
-#' Note that it is possible that the data contains a symbol from which there are 
-#' no transitions anywhere (even to itself), which would lead to a row in 
-#' transition matrix full of zeros. In this case the `build_mm` 
-#' (as well as the EM algorithm) assumes that the 
+#'
+#' Note that it is possible that the data contains a symbol from which there are
+#' no transitions anywhere (even to itself), which would lead to a row in
+#' transition matrix full of zeros. In this case the `build_mm`
+#' (as well as the EM algorithm) assumes that the
 #' the state is absorbing in a way that probability of staying in this state is 1.
 #'
 #' @seealso \code{\link{plot.hmm}} for plotting the model.
-#' 
+#'
 #' @examples
 #' # Construct sequence data
 #' data("mvad", package = "TraMineR")
 #'
 #' mvad_alphabet <-
 #'   c("employment", "FE", "HE", "joblessness", "school", "training")
-#' mvad_labels <- c("employment", "further education", "higher education",
-#'   "joblessness", "school", "training")
+#' mvad_labels <- c(
+#'   "employment", "further education", "higher education",
+#'   "joblessness", "school", "training"
+#' )
 #' mvad_scodes <- c("EM", "FE", "HE", "JL", "SC", "TR")
-#' mvad_seq <- seqdef(mvad, 17:86, alphabet = mvad_alphabet,
-#'   states = mvad_scodes, labels = mvad_labels, xtstep = 6)
+#' mvad_seq <- seqdef(mvad, 17:86,
+#'   alphabet = mvad_alphabet,
+#'   states = mvad_scodes, labels = mvad_labels, xtstep = 6
+#' )
 #'
 #' # Define a color palette for the sequence data
 #' attr(mvad_seq, "cpal") <- colorpalette[[6]]
@@ -53,58 +57,56 @@
 #' # Estimate the Markov model
 #' mm_mvad <- build_mm(observations = mvad_seq)
 #'
+build_mm <- function(observations) {
 
-build_mm <- function(observations){
-  
-  if(!inherits(observations, "stslist")){
-    stop("The build_mm function can only be used for single-channel sequence data (as an stslist object). Use the mc_to_sc_data function to convert multiple stslist into single-channel state sequences.")
+  multichannel <- is_multichannel(observations)
+  # Single channel but observations is a list
+  if (is.list(observations) && !inherits(observations, "stslist") && length(observations) == 1) {
+    observations <- observations[[1]]
+    multichannel <- FALSE
+  }
+  if (multichannel) {
+    stop(
+      paste0("The 'build_mm' function can only be used for single-channel ",
+             "sequence data (as an stslist object). Use the ",
+             "'mc_to_sc_data' function to convert data into single-channel ",
+             "state sequences."
+      )
+    )
   }
-  
-  n_sequences <- nrow(observations)
-  length_of_sequences <- ncol(observations)
   state_names <- alphabet(observations)
   n_states <- length(state_names)
+
   nobs <- sum(!(observations == attr(observations, "nr") |
                   observations == attr(observations, "void") |
                   is.na(observations)))
-  
+
 
   if (nobs < prod(dim(observations))) {
-    model <- fit_model(build_hmm(observations, 
-                                            transition_probs = matrix(1/n_states, n_states, n_states), 
-                                            emission_probs = diag(n_states),
-                                            initial_probs = rep(1 / n_states, n_states)))$model
-    warning("Sequences contain missing/void values, initial and transition probabilities estimated via EM. ")
-    initial_probs <- model$initial_probs
-    transition_probs <- model$transition_probs
+    model <- build_hmm(
+      observations,
+      transition_probs = matrix(1 / n_states, n_states, n_states),
+      emission_probs = diag(n_states),
+      initial_probs = rep(1 / n_states, n_states),
+      state_names = state_names)
+    model <- fit_model(model)$model
+    message("Sequences contain missing/void values, initial and transition probabilities estimated via EM. ")
   } else {
     first_timepoint <- suppressMessages(seqdef(observations[observations[, 1] %in% state_names, 1], alphabet = state_names))
     initial_probs <- TraMineR::seqstatf(first_timepoint)[, 2] / 100
     transition_probs <- suppressMessages(TraMineR::seqtrate(observations))
     zeros <- which(rowSums(transition_probs) == 0)
+    diag(transition_probs)[zeros] <- 1
     if (length(zeros) > 0) {
       warning("There are no observed transitions from some of the symbols.")
     }
-    diag(transition_probs)[zeros] <- 1
+    model <- build_hmm(
+      observations,
+      transition_probs = transition_probs,
+      emission_probs = diag(n_states),
+      initial_probs = initial_probs,
+      state_names = state_names)
   }
-  names(initial_probs) <- state_names
-  dimnames(transition_probs) <- list(from = state_names, to = state_names)
-  
-  emission_probs <- diag(n_states)
-  dimnames(emission_probs) <- dimnames(transition_probs)
-  
-  model <- structure(list(observations=observations,
-                          transition_probs=transition_probs,
-                          emission_probs=emission_probs,initial_probs=initial_probs,
-                          state_names=state_names,
-                          symbol_names=state_names, channel_names=NULL,
-                          length_of_sequences=length_of_sequences,
-                          n_sequences=n_sequences,
-                          n_symbols=n_states,n_states=n_states,
-                          n_channels=1), class = "hmm",
-                     nobs = nobs,
-                     df = sum(initial_probs > 0) - 1 + sum(transition_probs > 0) - n_states,
-                     type = "mm")
-  
+  attr(model, "type") <- "mm"
   model
 }
