@@ -1,4 +1,5 @@
 check_deprecated_args <- function(x) {
-  if (!is.null(x$withlegend))
+  if (!is.null(x$withlegend)) {
     stop("Argument `withlegend` is deprecated. Use `with.legend` instead.")
-}
\ No newline at end of file
+  }
+}
