@@ -8,23 +8,22 @@
 #' @param x Hidden Markov model of class \code{hmm} or \code{mhmm}.
 #' @param digits Minimum number of significant digits to print.
 #' @param ... Further arguments to \code{print.default}.
-#' @seealso \code{\link{build_hmm}} and \code{\link{fit_model}} for building and 
+#' @seealso \code{\link{build_hmm}} and \code{\link{fit_model}} for building and
 #'   fitting hidden Markov models.
-print.hmm <- function(x, digits = 3, ...){
-  
-  
+print.hmm <- function(x, digits = 3, ...) {
   if (x$n_channels == 1) {
-    if(attr(x, "type") == "mm"){
+    if (attr(x, "type") == "mm") {
       print.listof(list(
         "Initial probabilities" = x$initial_probs,
-        "Transition probabilities" = x$transition_probs), digits = digits, ...)
+        "Transition probabilities" = x$transition_probs
+      ), digits = digits, ...)
     } else {
       print.listof(list(
         "Initial probabilities" = x$initial_probs,
-        "Transition probabilities" = x$transition_probs, 
-        "Emission probabilities" = x$emission_probs), digits = digits, ...)
+        "Transition probabilities" = x$transition_probs,
+        "Emission probabilities" = x$emission_probs
+      ), digits = digits, ...)
     }
-  
   } else {
     print.listof(list("Initial probabilities" = x$initial_probs), digits = digits, ...)
     cat("\n")
@@ -34,5 +33,4 @@ print.hmm <- function(x, digits = 3, ...){
     print.listof(x$emission_probs, digits = digits, ...)
     cat("\n")
   }
-    
-}
\ No newline at end of file
+}
