@@ -45,58 +45,57 @@
 #' # Model summary
 #' summary(mhmm_biofam)
 #'
-#'
-
-summary.mhmm <- function(object, parameters = FALSE, conditional_se = TRUE,
-  log_space = FALSE, ...){
-
+summary.mhmm <- function(
+    object, parameters = FALSE, conditional_se = TRUE,
+    log_space = FALSE, ...) {
   partial_ll <- logLik(object, partials = TRUE, log_space = log_space)
   ll <- structure(sum(partial_ll), class = "logLik", df = attr(object, "df"), nobs = attr(object, "nobs"))
 
-  fw <- forward_backward(object, forward_only = TRUE, log_space = log_space)$forward_probs[,object$length_of_sequences,]
+  fw <- forward_backward(object, forward_only = TRUE, log_space = log_space)$forward_probs[, object$length_of_sequences, ]
 
-  pr <- exp(object$X%*%object$coefficients)
-  prior_cluster_probabilities <- pr/rowSums(pr)
+  pr <- exp(object$X %*% object$coefficients)
+  prior_cluster_probabilities <- pr / rowSums(pr)
 
 
   posterior_cluster_probabilities <- array(0, dim = dim(pr))
 
-  if(!log_space){
+  if (!log_space) {
     p <- 0
-    for(i in 1:object$n_clusters){
-      posterior_cluster_probabilities[,i] <- colSums(fw[(p+1):(p+object$n_states[i]), , drop = FALSE])
+    for (i in 1:object$n_clusters) {
+      posterior_cluster_probabilities[, i] <- colSums(fw[(p + 1):(p + object$n_states[i]), , drop = FALSE])
       p <- p + object$n_states[i]
     }
   } else {
     for (j in 1:object$n_sequences) {
       p <- 0
       for (i in 1:object$n_clusters) {
-        posterior_cluster_probabilities[j,i] <- exp(logSumExp(fw[(p+1):(p+object$n_states[i]), j]) - partial_ll[j])
+        posterior_cluster_probabilities[j, i] <- exp(logSumExp(fw[(p + 1):(p + object$n_states[i]), j]) - partial_ll[j])
         p <- p + object$n_states[i]
       }
-
     }
   }
   most_probable_cluster <- factor(apply(posterior_cluster_probabilities, 1, which.max),
-    levels = 1:object$n_clusters, labels = object$cluster_names)
+    levels = 1:object$n_clusters, labels = object$cluster_names
+  )
 
 
   clProbs <- matrix(NA, nrow = object$n_clusters, ncol = object$n_clusters)
   rownames(clProbs) <- colnames(clProbs) <- object$cluster_names
-  for(i in 1:object$n_clusters){
-    for(j in 1:object$n_clusters){
-      clProbs[i,j] <- mean(posterior_cluster_probabilities[most_probable_cluster == object$cluster_names[i], j])
+  for (i in 1:object$n_clusters) {
+    for (j in 1:object$n_clusters) {
+      clProbs[i, j] <- mean(posterior_cluster_probabilities[most_probable_cluster == object$cluster_names[i], j])
     }
   }
 
-  if(!parameters){
+  if (!parameters) {
     summary_mhmm <- list(
       logLik = ll, BIC = BIC(ll), most_probable_cluster = most_probable_cluster,
       coefficients = object$coefficients, vcov = vcov(object, conditional_se, log_space = log_space, ...),
       prior_cluster_probabilities = prior_cluster_probabilities,
       posterior_cluster_probabilities = posterior_cluster_probabilities,
-      classification_table = clProbs)
-  }else{
+      classification_table = clProbs
+    )
+  } else {
     summary_mhmm <- list(
       transition_probs = object$transition_probs,
       emission_probs = object$emission_probs,
@@ -105,7 +104,8 @@ summary.mhmm <- function(object, parameters = FALSE, conditional_se = TRUE,
       coefficients = object$coefficients, vcov = vcov(object, conditional_se, log_space = log_space, ...),
       prior_cluster_probabilities = prior_cluster_probabilities,
       posterior_cluster_probabilities = posterior_cluster_probabilities,
-      classification_table = clProbs)
+      classification_table = clProbs
+    )
   }
   class(summary_mhmm) <- "summary.mhmm"
   summary_mhmm
