@@ -1,6 +1,7 @@
 // Internal forward algorithm for HMMs and MHMMs using log-space
 
-#include "seqHMM.h"
+#include "forward_backward.h"
+#include "logsumexp.h"
 
 void log_internalForward(const arma::mat& transition, const arma::cube& emission,
   const arma::vec& init, const arma::ucube& obs, arma::cube& alpha, unsigned int threads) {
